
// Simple Demo using TBuffer64, Window display

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Hyper64; // Add Hyper64.pas to the library list

type
  TForm1 = class(TForm)
    procedure FormActivate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);

    // Define FormIdle
    // This func will contain the loop code
    // to be ran in the background
    procedure FormIdle(Sender: TObject; var Done : Boolean);
  private
    { Private declarations }
  public
    Hyper     : THyper64;  // Define our THyper64 object
    Buffer    : TBuffer64; // Define our TBuffer64 object
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

procedure TForm1.FormActivate(Sender: TObject);
begin
  // Start by
  // Creating a FullHyper object assigned
  // to TForm1.Handle wich points to our window.
  // In TFullHyper64 you must specify the Color Depth
  Hyper:= THyper64.Create(Handle, 640, 480);

  // Create a Buffer, each buffer must be associated
  // with one of the THyper64 type classes,
  // like THyper64, TFullHyper64 or TSelfHyper64.
  // When using fullscreen modes ONLY ONE
  // THyper64 is possible, a TFullHyper64 or
  // a TSelfHyper64

  // The last parameter refers to wether we
  // wan't Video Memory or System Memory
  // NOTE that Video Memory has hardware acceleration
  //      in blit and fill funcs, but system memory is
  //      faster when using lots of primitives
  Buffer:= TBuffer64.Create(Hyper, 640, 480, false);

  // Assign our loop func to our
  // application idle process
  Application.OnIdle:= FormIdle;
end;

procedure TForm1.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  // Free Memory in the end
  Buffer.Destroy;
  Hyper.Destroy;
end;

// This func will contain the loop code
// to be ran in the background
procedure TForm1.FormIdle(Sender: TObject; var Done : Boolean);
var i : longint;
begin
  // Draw 10 lines random Line to Buffer
  for i:= 0 to 9 do
    Buffer.Line(random(640), random(480),
                random(640), random(480), random(65536));
  // Flip Buffer to the Front Display using
  // VSync (retrace wait) 
  Buffer.Flip(true);
  // Flip is optimized to buffers with the same size
  // as it's associated Hyper, so if you have buffers with
  // other sizes use Buffer.Draw(X, Y) or any other of the
  // Draw type

  Done:= false; // Loop again
end;

end.
 